@@ -99,4 +99,8 @@ int    datecmp( Date *date1, Date *date2 );
 
 /** GLOBALS *********************************************************/
 
+#define DATE_SHORT 0
+#define DATE_YEAR  1
+#define DATE_FULL  2
+
 #endif /* __XACC_DATE_H__ */
